@@ -29,6 +29,6 @@ class Command(BaseCommand):
             # Consumer does not exist in INGRESS_CONSUMER_CLASSES
             self.stderr.write(str(e))
         else:
-            self.stdout.write("Starting consumer 'consumer_class'")
+            self.stdout.write(f"Starting consumer for '{collection_name}'")
             consumer = consumer_class()
             consumer.consume()
