@@ -33,6 +33,6 @@ class Command(BaseCommand):
                     "yes" if c.consumer_enabled else "no",
                     c.message_set.filter(consume_started_at__isnull=True).count(),
                     c.failedmessage_set.count(),
-                    c.url_path,
+                    c.url_path or "None",
                 )
             )
