@@ -3,6 +3,7 @@ import traceback
 
 from django.db import models
 from django.urls import reverse
+from django.urls.exceptions import NoReverseMatch
 from django.utils import timezone
 
 from ingress.querysets import FailedMessageQuerySet, MessageQuerySet
@@ -24,7 +25,10 @@ class Collection(models.Model):
 
     @property
     def url_path(self):
-        return reverse('ingress', kwargs={'collection_name': self.name})
+        try:
+            return reverse('ingress', kwargs={'collection_name': self.name})
+        except NoReverseMatch:
+            return None
 
 
 class BaseMessage(models.Model):
